import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/*
  * created by trongtrong
  * on 17/05/2021
* */

class NPButton extends StatefulWidget {
  /*
    determine state of widget
  */
  final bool isActive;

  /*
    width of widget
  */
  final double width;

  /*
    height of widget
  */
  final double height;

  /*
    value color that indicate origin state of button when active
  */
  final Color defaultActiveColor;

  /*
    value color that indicate origin state of button when disable
  */
  final Color defaultDisableColor;

  /*
    value color that indicate user press button
  */
  final Color highlightColor;

  /*
    title of button
  */
  final String title;

  final VoidCallback onPressed;

  final Color colorText;

  const NPButton(
      {Key key,
      this.isActive = true,
      this.width,
      this.height,
      this.defaultActiveColor,
      this.defaultDisableColor,
      this.highlightColor,
      this.colorText,
      @required this.title,
      @required this.onPressed})
      : super(key: key);

  factory NPButton.primary(
      {Key key,
      @required bool isActive,
      @required String title,
      @required Function() onPressed}) {
    return NPButton(
      isActive: isActive,
      title: title,
      onPressed: onPressed,
      defaultActiveColor: const Color(0xFF15AE62),
      defaultDisableColor: const Color(0xFFE6E8E9),
      highlightColor: const Color(0xFF0E864A),
      colorText: Colors.white,
    );
  }

  factory NPButton.secondary(
      {Key key,
      @required bool isActive,
      @required String title,
      @required Function() onPressed}) {
    return NPButton(
      isActive: isActive,
      title: title,
      onPressed: onPressed,
      defaultActiveColor: const Color(0xFFF4F6FA),
      defaultDisableColor: const Color(0xFFF4F6FA),
      highlightColor: const Color(0xFFF4FAF5),
      colorText: Color(0xFF15AE62),
    );
  }

  @override
  _NPButtonState createState() => _NPButtonState();
}

class _NPButtonState extends State<NPButton> {
  bool isEnableClick = true;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width == null ? double.infinity : widget.width,
      height: widget.height == null ? 44 : widget.height,
      child: TextButton(
        style: ButtonStyle(
          backgroundColor: MaterialStateProperty.all(widget.isActive
              ? widget.defaultActiveColor
              : widget.defaultDisableColor),
          overlayColor: MaterialStateColor.resolveWith((states) {
            return widget.isActive
                ? widget.highlightColor
                : widget.defaultDisableColor;
          }),
        ),
        child: Text(
          widget.title,
          style:
              TextStyle(color: widget.colorText, fontWeight: FontWeight.w600),
        ),
        onPressed: () {
          if (!widget.isActive) return;
          if (isEnableClick) widget.onPressed();
          setState(() {
            isEnableClick = false;
          });
          Future.delayed(Duration(milliseconds: 200), () {
            setState(() {
              isEnableClick = true;
            });
          });
        },
      ),
    );
  }
}
