import 'package:flutter/material.dart';

import 'colors.dart';

class RatioScreenApp {
  static double _ratio;
  static RatioScreenApp _singleton = RatioScreenApp._instance();

  /// Phải gọi trong hàm build khi khởi tạo tỷ lệ
  ///
  /// Nếu không gọi thì sẽ mặc định tỷ lệ là 1.0
  factory RatioScreenApp.setRatio(double value) {
    if (_ratio == null) {
      _ratio = value ?? 1;
    }
    return _singleton;
  }

  RatioScreenApp._instance();
  static double getRatio() => _ratio ?? 1.0;
}

extension FontScale on Text {
  static double myRatio = RatioScreenApp.getRatio();
  Text h0({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 46 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h1({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 38 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h2({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 24 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h3({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 20 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h4({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 18 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h5({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 16 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h6({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 14 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h7({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 12 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));
  Text h8({Color color}) => _copyWith(
      style: TextStyle(
          fontSize: 11 * myRatio,
          fontWeight: FontWeight.w600,
          color: color ?? titleTextColor));

  Text _copyWith(
      {Key key,
      StrutStyle strutStyle,
      TextAlign textAlign,
      TextDirection textDirection = TextDirection.ltr,
      Locale locale,
      bool softWrap,
      TextOverflow overflow,
      double textScaleFactor,
      int maxLines,
      String semanticsLabel,
      TextWidthBasis textWidthBasis,
      TextStyle style}) {
    return Text(this.data,
        key: key ?? this.key,
        strutStyle: strutStyle ?? this.strutStyle,
        textAlign: textAlign ?? this.textAlign,
        textDirection: textDirection ?? this.textDirection,
        locale: locale ?? this.locale,
        softWrap: softWrap ?? this.softWrap,
        overflow: overflow ?? this.overflow,
        textScaleFactor: textScaleFactor ?? this.textScaleFactor,
        maxLines: maxLines ?? this.maxLines,
        semanticsLabel: semanticsLabel ?? this.semanticsLabel,
        textWidthBasis: textWidthBasis ?? this.textWidthBasis,
        style: style != null ? this.style?.merge(style) ?? style : this.style);
  }
}
